@@ -15,7 +15,7 @@ pub async fn main() {
 
     tokio::pin!(output);
 
-    while let Some(output) = output.as_mut().next_pinned().await {
+    while let Some(output) = output.as_mut().next().await {
         dbg!(output);
     }
 }
